[![CI](https://github.com/google/pycnite/workflows/CI/badge.svg?branch=main)](https://github.com/google/pycnite/actions)
[![PyPI - Wheel](https://img.shields.io/pypi/wheel/pycnite)](https://pypi.org/project/pycnite/#files)

# pycnite

A collection of utilities for working with compiled Python bytecode.

This library adds pure Python, versioned parsers for the .pyc format, allowing
tools that work with bytecode to have different host and target Python versions.

Currently supported target versions: 3.8, 3.9, 3.10, 3.11 and 3.12
